@@ -118,7 +118,14 @@ private:
 
 
 struct Rect {
-    int l, t, r, b;
+    int left;
+    int top;
+    int right;
+    int bottom;
+};
+
+struct Dim {
+    int w, h;
 };
 
 static inline int align(int value, int alignment) {
@@ -151,8 +158,6 @@ typedef struct ReconfigParams_t {
     uint32_t reconfig_flush_mode;
 } ReconfigParams;
 
-int GetEnvVar(const char *name, int &dev_count);
-
 class RocVideoDecoder {
     public:
       /**
@@ -317,6 +322,11 @@ class RocVideoDecoder {
          */
         void SaveFrameToFile(std::string output_file_name, void *surf_mem, OutputSurfaceInfo *surf_info);
 
+        /**
+         * @brief Helper funtion to close a existing file and dump to new file in case of multiple files using same decoder
+        */
+       void ResetSaveFrameToFile();
+
         /**
          * @brief Helper function to start MD5 calculation
          */
@@ -420,7 +430,6 @@ class RocVideoDecoder {
         rocDecVideoCodec codec_id_ = rocDecVideoCodec_NumCodecs;
         rocDecVideoChromaFormat video_chroma_format_ = rocDecVideoChromaFormat_420;
         rocDecVideoSurfaceFormat video_surface_format_ = rocDecVideoSurfaceFormat_NV12;
-        RocdecVideoFormat video_format_ = {};
         RocdecSeiMessageInfo *curr_sei_message_ptr_ = nullptr;
         RocdecSeiMessageInfo sei_message_display_q_[MAX_FRAME_NUM];
         int decoded_frame_cnt_ = 0, decoded_frame_cnt_ret_ = 0;
@@ -433,6 +442,8 @@ class RocVideoDecoder {
         uint32_t disp_width_ = 0;
         uint32_t coded_height_ = 0;
         uint32_t disp_height_ = 0;
+        uint32_t target_width_ = 0;
+        uint32_t target_height_ = 0;
         int max_width_ = 0, max_height_ = 0;
         uint32_t chroma_height_ = 0;
         uint32_t num_chroma_planes_ = 0;
@@ -444,8 +455,8 @@ class RocVideoDecoder {
         std::mutex mtx_vp_frame_;
         std::vector<DecFrameBuffer> vp_frames_;      // vector of decoded frames
         std::queue<DecFrameBuffer> vp_frames_q_;
-        Rect disp_rect_ = {};
-        Rect crop_rect_ = {};
+        Rect disp_rect_ = {}; // displayable area specified in the bitstream
+        Rect crop_rect_ = {}; // user specified region of interest within diplayable area disp_rect_
         FILE *fp_sei_ = NULL;
         FILE *fp_out_ = NULL;
         struct AVMD5 *md5_ctx_;
